@@ -10,11 +10,11 @@ from python3_anticaptcha import app_key, create_task_url, get_sync_result, get_a
 class FunCaptchaTaskProxyless:
     def __init__(self, anticaptcha_key: str, sleep_time: int = 5, callbackUrl: str = None):
         """
-		Модуль отвечает за решение FunCaptcha Proxyless
-		:param anticaptcha_key: Ключ от АнтиКапчи
-		:param sleep_time: Время ожидания решения
+        Модуль отвечает за решение FunCaptcha Proxyless
+        :param anticaptcha_key: Ключ от АнтиКапчи
+        :param sleep_time: Время ожидания решения
         :param callbackUrl: URL для решения капчи с ответом через callback
-		"""
+        """
         if sleep_time < 5:
             raise ValueError(f"Param `sleep_time` must be greater than 5. U set - {sleep_time}")
         self.sleep_time = sleep_time
@@ -44,21 +44,19 @@ class FunCaptchaTaskProxyless:
     # Работа с капчёй
     def captcha_handler(self, websiteURL: str, data: str, websitePublicKey: str, **kwargs) -> dict:
         """
-		Метод получает ссылку на страницу на которпой расположена капча и ключ капчи
-		:param websiteURL: Ссылка на страницу с капчёй
-		:param data: Дополнительный параметр, который может требоваться для некоторых решений фанкапчи.
-		:param websitePublicKey: Ключ капчи(как его получить - описано в документаии на сайте антикапчи)
+                Метод получает ссылку на страницу на которпой расположена капча и ключ капчи
+                :param websiteURL: Ссылка на страницу с капчёй
+                :param data: Дополнительный параметр, который может требоваться для некоторых решений фанкапчи.
+                :param websitePublicKey: Ключ капчи(как его получить - описано в документаии на сайте антикапчи)
         :param kwargs: Дополнительные параметры для `requests.post(....)`.
-		:return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
-		"""
+                :return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
+        """
         self.task_payload["task"].update(
             {"websiteURL": websiteURL, "data": data, "websitePublicKey": websitePublicKey}
         )
         # Отправляем на антикапча параметры фанкапич,
         # в результате получаем JSON ответ содержащий номер решаемой капчи
-        captcha_id = requests.post(
-            create_task_url, json=self.task_payload, verify=False, **kwargs
-        ).json()
+        captcha_id = requests.post(create_task_url, json=self.task_payload, verify=False, **kwargs).json()
 
         # Проверка статуса создания задачи, если создано без ошибок - извлекаем ID задачи, иначе возвращаем ответ сервера
         if captcha_id["errorId"] == 0:
@@ -80,11 +78,11 @@ class FunCaptchaTaskProxyless:
 class aioFunCaptchaTaskProxyless:
     def __init__(self, anticaptcha_key: str, sleep_time: int = 5, callbackUrl: str = None):
         """
-		Модуль отвечает за решение FunCaptcha Proxyless
-		:param anticaptcha_key: Ключ от АнтиКапчи
-		:param sleep_time: Время ожидания решения
+                Модуль отвечает за решение FunCaptcha Proxyless
+                :param anticaptcha_key: Ключ от АнтиКапчи
+                :param sleep_time: Время ожидания решения
         :param callbackUrl: URL для решения капчи с ответом через callback
-		"""
+        """
         if sleep_time < 5:
             raise ValueError(f"Param `sleep_time` must be greater than 5. U set - {sleep_time}")
         self.sleep_time = sleep_time
@@ -106,12 +104,12 @@ class aioFunCaptchaTaskProxyless:
     # Работа с капчёй
     async def captcha_handler(self, websiteURL: str, data: str, websitePublicKey: str) -> dict:
         """
-		Метод получает ссылку на страницу на которпой расположена капча и ключ капчи
-		:param websiteURL: Ссылка на страницу с капчёй
-		:param data: Дополнительный параметр, который может требоваться для некоторых решений фанкапчи.
-		:param websitePublicKey: Ключ капчи(как его получить - описано в документаии на сайте антикапчи)
-		:return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
-		"""
+        Метод получает ссылку на страницу на которпой расположена капча и ключ капчи
+        :param websiteURL: Ссылка на страницу с капчёй
+        :param data: Дополнительный параметр, который может требоваться для некоторых решений фанкапчи.
+        :param websitePublicKey: Ключ капчи(как его получить - описано в документаии на сайте антикапчи)
+        :return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
+        """
         self.task_payload["task"].update(
             {"websiteURL": websiteURL, "data": data, "websitePublicKey": websitePublicKey}
         )
@@ -136,6 +134,4 @@ class aioFunCaptchaTaskProxyless:
         else:
             # Ждем решения капчи
             await asyncio.sleep(self.sleep_time)
-            return await get_async_result(
-                result_payload=self.result_payload, sleep_time=self.sleep_time
-            )
+            return await get_async_result(result_payload=self.result_payload, sleep_time=self.sleep_time)
